durationtools.multiply_duration_pair_and_reduce_factors
=======================================================

.. autofunction:: abjad.tools.durationtools.multiply_duration_pair_and_reduce_factors.multiply_duration_pair_and_reduce_factors
